@@ -14,9 +14,9 @@
  * SOFTWARE.
  */
 
-use crate::dmntk_common::DmntkError;
 use crate::point::Point;
 use crate::rect::Rect;
+use dmntk_common::DmntkError;
 
 #[derive(Debug, PartialEq)]
 pub enum RecognizerError {
