@@ -16,16 +16,14 @@
 
 //! Plane.
 
-use {
-  crate::{
-    errors::*,
-    point::Point,
-    rect::{Rect, RECT_ZERO},
-  },
-  dmntk_common::Result,
-  dmntk_model::model::HitPolicy,
-  std::{collections::HashSet, convert::TryFrom, str::FromStr},
-};
+use crate::errors::*;
+use crate::point::Point;
+use crate::rect::{Rect, RECT_ZERO};
+use dmntk_common::Result;
+use dmntk_model::model::HitPolicy;
+use std::collections::HashSet;
+use std::convert::TryFrom;
+use std::str::FromStr;
 
 /// Cell on the plane.
 #[derive(Debug, PartialEq)]
